@@ -16,7 +16,7 @@ Usage::
     session_client: FinSpaceDataClient = session.client("finspace-data")
     ```
 """
-from mypy_boto3_finspace_data.client import FinSpaceDataClient
+from .client import FinSpaceDataClient
 
 Client = FinSpaceDataClient
 
